AclMode

Struct AclMode 

pub struct AclMode(/* private fields */);
A bit flag representing all the privileges that can be granted to a role.

Modeled after: https://github.com/postgres/postgres/blob/7f5b19817eaf38e70ad1153db4e644ee9456853e/src/include/nodes/parsenodes.h#L74-L101

The lower 32 bits are used for different privilege types.

The upper 32 bits indicate a grant option on the privilege for the current bit shifted right by 32 bits (Currently unimplemented in Materialize).

Privileges that exist in Materialize but not PostgreSQL start at the highest available bit and move down towards the PostgreSQL compatible bits. This is try to avoid collisions with privileges that PostgreSQL may add in the future.

Implementations

Source

impl AclMode

pub const INSERT: Self

pub const SELECT: Self

pub const UPDATE: Self

pub const DELETE: Self

pub const USAGE: Self

pub const CREATE: Self

pub const CREATE_CLUSTER: Self

pub const CREATE_DB: Self

pub const CREATE_ROLE: Self

pub const CREATE_NETWORK_POLICY: Self

Source

impl AclMode

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u64

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u64) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u64) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u64) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in self are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in other are also set in self.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in other are also set in self.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in self and other.

pub fn remove(&mut self, other: Self)

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in self and other.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in self and other.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in self and other.

pub const fn difference(self, other: Self) -> Self

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in self and other.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in self, truncating the result.

Source

impl AclMode

pub const fn iter(&self) -> Iter<AclMode> ⓘ

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<AclMode> ⓘ

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl AclMode

pub fn parse_single_privilege(s: &str) -> Result<Self, Error>

pub fn parse_multiple_privileges(s: &str) -> Result<Self, Error>

pub fn to_error_string(&self) -> String

pub fn explode(&self) -> Vec<&'static str>