pub type Numeric = Decimal<NUMERIC_DATUM_WIDTH_USIZE>;Expand description
A numeric value.
Aliased Type
#[repr(C)]pub struct Numeric { /* private fields */ }Trait Implementations
Sourceimpl AsColumnType for Numeric
impl AsColumnType for Numeric
Sourcefn as_column_type() -> SqlColumnType
fn as_column_type() -> SqlColumnType
The SQL column type of this Rust type
Sourceimpl DecimalLike for Numeric
impl DecimalLike for Numeric
Sourcefn lossy_from(i: i64) -> Self
fn lossy_from(i: i64) -> Self
Used to do value-to-value conversions while consuming the input value. Depending on the
implementation it may be potentially lossy.
Sourceimpl<'a, E> InputDatumType<'a, E> for Numeric
impl<'a, E> InputDatumType<'a, E> for Numeric
Sourcefn try_from_result(
res: Result<Datum<'a>, E>,
) -> Result<Self, Result<Datum<'a>, E>>
fn try_from_result( res: Result<Datum<'a>, E>, ) -> Result<Self, Result<Datum<'a>, E>>
Try to convert a Result whose Ok variant is a Datum into this native Rust type (Self). If
it fails the error variant will contain the original result.
Sourcefn all_nullable() -> bool
fn all_nullable() -> bool
Whether ALL components of this input accept NULL values. Read more