pub enum SemanticType {
Show 20 variants
CatalogItemId,
GlobalId,
ClusterId,
ReplicaId,
SchemaId,
DatabaseId,
RoleId,
NetworkPolicyId,
ShardId,
OID,
ObjectType,
ConnectionType,
SourceType,
MzTimestamp,
WallclockTimestamp,
ByteCount,
RecordCount,
CreditRate,
SqlDefinition,
RedactedSqlDefinition,
}Expand description
Semantic type annotation for a column in a builtin catalog relation.
These are compile-time metadata used by the catalog ontology layer to
describe the meaning of a column (e.g., that it contains a catalog item ID
or a role ID). Possible values correspond to the entries in
SEMANTIC_TYPE_DEFS in the mz-catalog crate.
Variants
CatalogItemId
GlobalId
ClusterId
ReplicaId
SchemaId
DatabaseId
RoleId
NetworkPolicyId
ShardId
OID
ObjectType
ConnectionType
SourceType
MzTimestamp
WallclockTimestamp
ByteCount
RecordCount
CreditRate
SqlDefinition
RedactedSqlDefinition