ToDatumIter

Trait ToDatumIter 

pub trait ToDatumIter: Sized {
    type DatumIter<'a>: IntoIterator<Item = Datum<'a>>
       where Self: 'a;

    // Required method
    fn to_datum_iter(&self) -> Self::DatumIter<'_>;
}
A helper trait to turn a type into an iterator of datums.

Required Associated Types

type DatumIter<'a>: IntoIterator<Item = Datum<'a>> where Self: 'a

An iterator type for use in to_datum_iter.

Required Methods

fn to_datum_iter(&self) -> Self::DatumIter<'_>

Obtains an iterator of datums out of an instance of &Self.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<'b, T: ToDatumIter> ToDatumIter for &'b T

Source

type DatumIter<'a> = <T as ToDatumIter>::DatumIter<'a> where Self: 'a

Source

fn to_datum_iter(&self) -> Self::DatumIter<'_>

Implementors

Source

impl ToDatumIter for Row

Source

type DatumIter<'a> = DatumListIter<'a>