pub struct OptionalArg<T>(pub Option<T>);Expand description
Wrapper to distinguish “argument may not be present” from Option<T> (nullable).
Tuple Fields
0: Option<T>Methods from Deref<Target = Option<T>>
1.0.0 · Sourcepub fn as_ref(&self) -> Option<&T>
pub fn as_ref(&self) -> Option<&T>
Converts from &Option<T> to Option<&T>.
Examples
Calculates the length of an Option<String> as an Option<usize>
without moving the String. The map method takes the self argument by value,
consuming the original, so this technique uses as_ref to first take an Option to a
reference to the value inside the original.
let text: Option<String> = Some("Hello, world!".to_string());
// First, cast `Option<String>` to `Option<&String>` with `as_ref`,
// then consume *that* with `map`, leaving `text` on the stack.
let text_length: Option<usize> = text.as_ref().map(|s| s.len());
println!("still can print text: {text:?}");1.75.0 · Sourcepub fn as_slice(&self) -> &[T]
pub fn as_slice(&self) -> &[T]
Returns a slice of the contained value, if any. If this is None, an
empty slice is returned. This can be useful to have a single type of
iterator over an Option or slice.
Note: Should you have an Option<&T> and wish to get a slice of T,
you can unpack it via opt.map_or(&[], std::slice::from_ref).
Examples
assert_eq!(
[Some(1234).as_slice(), None.as_slice()],
[&[1234][..], &[][..]],
);The inverse of this function is (discounting
borrowing) [_]::first:
for i in [Some(1234_u16), None] {
assert_eq!(i.as_ref(), i.as_slice().first());
}1.40.0 · Sourcepub fn as_deref(&self) -> Option<&<T as Deref>::Target>where
T: Deref,
pub fn as_deref(&self) -> Option<&<T as Deref>::Target>where
T: Deref,
Converts from Option<T> (or &Option<T>) to Option<&T::Target>.
Leaves the original Option in-place, creating a new one with a reference
to the original one, additionally coercing the contents via Deref.
Examples
let x: Option<String> = Some("hey".to_owned());
assert_eq!(x.as_deref(), Some("hey"));
let x: Option<String> = None;
assert_eq!(x.as_deref(), None);Trait Implementations
Sourceimpl<T: Clone> Clone for OptionalArg<T>
impl<T: Clone> Clone for OptionalArg<T>
Sourcefn clone(&self) -> OptionalArg<T>
fn clone(&self) -> OptionalArg<T>
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl<T: Debug> Debug for OptionalArg<T>
impl<T: Debug> Debug for OptionalArg<T>
Sourceimpl<T> Deref for OptionalArg<T>
impl<T> Deref for OptionalArg<T>
Sourceimpl<T> From<Option<T>> for OptionalArg<T>
impl<T> From<Option<T>> for OptionalArg<T>
Sourceimpl<T: Hash> Hash for OptionalArg<T>
impl<T: Hash> Hash for OptionalArg<T>
Sourceimpl<'a, E, T: InputDatumType<'a, E>> InputDatumType<'a, E> for OptionalArg<T>
impl<'a, E, T: InputDatumType<'a, E>> InputDatumType<'a, E> for OptionalArg<T>
Sourcefn try_from_result(
res: Result<Datum<'a>, E>,
) -> Result<Self, Result<Datum<'a>, E>>
fn try_from_result( res: Result<Datum<'a>, E>, ) -> Result<Self, Result<Datum<'a>, E>>
Sourcefn try_from_iter(
iter: &mut impl Iterator<Item = Result<Datum<'a>, E>>,
) -> Result<Self, Result<Option<Datum<'a>>, E>>
fn try_from_iter( iter: &mut impl Iterator<Item = Result<Datum<'a>, E>>, ) -> Result<Self, Result<Option<Datum<'a>>, E>>
Sourcefn all_nullable() -> bool
fn all_nullable() -> bool
Sourceimpl<T: Ord> Ord for OptionalArg<T>
impl<T: Ord> Ord for OptionalArg<T>
Sourcefn cmp(&self, other: &OptionalArg<T>) -> Ordering
fn cmp(&self, other: &OptionalArg<T>) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Sourceimpl<T: PartialEq> PartialEq for OptionalArg<T>
impl<T: PartialEq> PartialEq for OptionalArg<T>
Sourceimpl<T: PartialOrd> PartialOrd for OptionalArg<T>
impl<T: PartialOrd> PartialOrd for OptionalArg<T>
impl<T: Copy> Copy for OptionalArg<T>
impl<T: Eq> Eq for OptionalArg<T>
impl<T> StructuralPartialEq for OptionalArg<T>