pub struct Rows {
bytes: Bytes,
run_start: usize,
run_ends: SharedSlice<usize>,
}Expand description
A packed representation of a set of rows.
Fields
bytes: Bytesrun_start: usizeAfter a split, the bytes above will only cover the range of bytes currently contained in this Rows, but the shared slice ends contain offsets into the original un-split buffer. That means we need to track the offset that corresponds to the first byte in the bytes buffer, to offset the rest of the values with. That’s what this value is!
run_ends: SharedSlice<usize>Implementations
Sourceimpl Rows
impl Rows
pub fn builder(byte_size_hint: usize, row_size_hint: usize) -> RowsBuilder
pub fn get(&self, index: usize) -> Option<&RowRef>
pub fn iter(&self) -> impl Iterator<Item = &RowRef>
pub fn split_at(self, mid: usize) -> (Self, Self)
pub fn len(&self) -> usize
pub fn byte_len(&self) -> usize